@@ -7,8 +7,8 @@ from typing import List, Sequence, Callable
 from pyqtgraph.parametertree import Parameter
 from pyqtgraph.parametertree.parameterTypes import GroupParameter
 
-from ..fns import getParamChild, docParser
 from .prjparam import PrjParam
+from .. import fns
 from ..misc import CompositionMixin
 from ..processing import *
 
@@ -38,7 +38,7 @@ def addStageToParam(stage: ProcessStage, parentParam: Parameter, **kwargs):
 @addStageToParam.register
 def addAtomicToParam(stage: AtomicProcess, parentParam: Parameter,
                  argNameFormat: Callable[[str], str]=None, **kwargs):
-  docParams = docParser(stage.func.__doc__)
+  docParams = fns.docParser(stage.func.__doc__)
   params: List[Parameter] = []
   for key in stage.input.hyperParamKeys:
     val = stage.input[key]
@@ -53,11 +53,38 @@ def addAtomicToParam(stage: AtomicProcess, parentParam: Parameter,
     paramDict = curParam.toPgDict()
     if argNameFormat is not None and 'title' not in paramDict:
       paramDict['title'] = argNameFormat(key)
-    pgParam = getParamChild(parentParam, chOpts=paramDict)
+    pgParam = fns.getParamChild(parentParam, chOpts=paramDict)
+    _hookupCondition(parentParam, pgParam)
     params.append(pgParam)
   stage.run = atomicRunWrapper(stage, stage.input.hyperParamKeys, params)
   return stage
 
+def _hookupCondition(parentParam: Parameter, chParam: Parameter):
+  condition = chParam.opts.get('condition', None)
+  if not condition:
+    return
+  _locals = {p.name(): p.value() for p in parentParam}
+  if isinstance(condition, str):
+    def cndtnCallable():
+      exec(f'__out__ = bool({condition})', {}, _locals)
+      # noinspection PyUnresolvedReferences
+      return _locals['__out__']
+  else:
+    cndtnCallable = condition
+  def onChanged(param, val):
+    _locals[param.name()] = val
+    if cndtnCallable():
+      chParam.show()
+    else:
+      chParam.hide()
+
+  ch = None
+  for ch in parentParam: ch.sigValueChanging.connect(onChanged)
+  # Triger in case condition is initially false
+  if ch:
+    onChanged(ch, ch.value())
+
+
 @addStageToParam.register
 def addNestedToParam(stage: NestedProcess, parentParam: Parameter, nestHyperparams=True,
                      argNameFormat: Callable[[str], str]=None, treatAsAtomic=False, **kwargs):
@@ -82,7 +109,7 @@ def addNestedToParam(stage: NestedProcess, parentParam: Parameter, nestHyperpara
     if nestHyperparams:
       paramDict = PrjParam(name=childStage.name, pType=pType, value=[],
                           enabled=not childStage.disabled).toPgDict()
-      parentParam = getParamChild(outerParent, chOpts=paramDict)
+      parentParam = fns.getParamChild(outerParent, chOpts=paramDict)
     else:
       parentParam = outerParent
     addStageToParam(childStage, parentParam)
@@ -98,7 +125,7 @@ class NestedProcWrapper(CompositionMixin):
     if parentParam is None:
       parentParam = Parameter.create(name=self.algName, type='group')
     elif nestHyperparams:
-      parentParam = getParamChild(parentParam, self.algName)
+      parentParam = fns.getParamChild(parentParam, self.algName)
     self.parentParam : GroupParameter = parentParam
     self.addStage(self.processor)
 
