@@ -463,6 +463,11 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
 
   def __init__(self, imgSrc: np.ndarray=None, **kwargs):
     super().__init__(**kwargs)
+    self.pxColorLbl, self.mouseCoordsLbl = None, None
+    """
+    Set these to QLabels to have up-to-date information about the image coordinates
+    under the mouse (if self.mouseEnabled = True)    
+    """
     self.toolsEditor = params.ParamEditor(name='Region Tools')
     vb = self.getViewBox()
     self.menu: QtWidgets.QMenu = vb.menu
@@ -484,12 +489,27 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
     self.addItem(self.imgItem)
     if imgSrc is not None:
       self.setImage(imgSrc)
+    self.sigSceneMouseMoved.connect(self._onMouseMove)
+    self.mouseEnabled = True
 
-  def updateCursorClr(self, xyPos: np.ndarray, pxColor: np.ndarray):
+  def _onMouseMove(self, pos: QtCore.QPointF):
+    relpos = self.imgItem.mapFromScene(pos)
+    xyCoord = np.array([relpos.x(), relpos.y()], dtype=int)
+    if (self.imgItem.image is None
+        or np.any(xyCoord < 0)
+        or np.any(xyCoord > self.imgItem.image.shape[:2][::-1])):
+      return
+    cursorClr = self.imgItem.image[xyCoord[1], xyCoord[0],...].astype(int)
+    self.updateCursorInfo(xyCoord, cursorClr)
+
+  def updateCursorInfo(self, xyPos: np.ndarray, pxColor: np.ndarray):
     if pxColor is None: return
-    self.mouseCoords.setText(f'Mouse (x,y): {xyPos[0]}, {xyPos[1]}'
-                             f' | Pixel Color: ')
-    self.pxColor.setText(f'{pxColor}')
+    if self.mouseCoordsLbl is not None:
+      self.mouseCoordsLbl.setText(f'Mouse (x,y): {xyPos[0]}, {xyPos[1]}')
+
+    if self.pxColorLbl is None:
+      return
+    self.pxColorLbl.setText(f'Pixel Color: {pxColor}')
     if pxColor.dtype == float:
       # Turn to uint
       pxColor = (pxColor*255).astype('uint8')
@@ -505,7 +525,7 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
       fontColor = 'black'
     else:
       fontColor = 'white'
-    self.pxColor.setStyleSheet(f'background:rgba{tuple(pxColor)}; color:{fontColor}')
+    self.pxColorLbl.setStyleSheet(f'background:rgba{tuple(pxColor)}; color:{fontColor}')
 
   def setImage(self, imgSrc: t.Union[FilePath, np.ndarray]=None):
     """
@@ -526,6 +546,35 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
     else:
       self.imgItem.setImage(imgSrc)
 
+  def widgetContainer(self, asMainWin=False, **kwargs):
+    """
+    Though this is a PlotWidget class, it has a lot of widget children (toolsEditor group, buttons) that are
+    not visible when spawning the widget. This is a convenience method that creates a new, outer widget
+    from all teh graphical elements of an EditableImage.
+
+    :param asMainWin: Whether to return a QMainWindow or QWidget
+    :param kwargs: Passed to either EasyWidget.buildMainWin or EasyWidget.BuildWidget,
+      depending on the value of `asMainWin`
+    """
+    if asMainWin:
+      wid = EasyWidget.buildMainWin(self._widgetContainerChildren(), **kwargs)
+      self.mouseCoordsLbl = QtWidgets.QLabel()
+      self.pxColorLbl = QtWidgets.QLabel()
+      wid.statusBar().addWidget(self.mouseCoordsLbl)
+      wid.statusBar().addWidget(self.pxColorLbl)
+      wid.addDockWidget(QtCore.Qt.RightDockWidgetArea, self.toolsEditor)
+    else:
+      wid = EasyWidget.buildWidget(self._widgetContainerChildren(), **kwargs)
+    return wid
+
+
+  def _widgetContainerChildren(self):
+    """
+    Returns the children that should be added to the container when widgetContainer()
+    is called
+    """
+    return [self]
+
 class CompositorItemSample(ItemSample):
   def paint(self, p: QtGui.QPainter, *args):
     opts = self.item.opts
@@ -707,7 +756,7 @@ class MaskCompositor(ImageViewer):
       self.viewbox.removeItem(imgItem)
     self.recordDf = self.recordDf.drop(self.recordDf.index)
     self.legend.clear()
-    self.toolsEditor.params.child('Masks').clear()
+    self.toolsEditor.params.child('Masks').clearChildren()
 
   def toggleAllVisible(self):
     for param in self.masksParam:
